@@ -2,7 +2,8 @@ from .dagster_types import DataFrameType, MLFlowRunType, ModelType, SeriesType
 from .inference.base import InferenceComponent
 from .inference.mlflow import MLFlowInferenceComponent
 from .loader.dataframe import DataFrameLoader
-from .resources.io_manager import io_manager
+from .loader.sql_table import SqlTableLoader
+from .resources.io_manager import qdk_io_manager
 from .s3_connection import S3Connection
 from .training.base import TrainingComponent
 from .training.doc2vec import Doc2VecTrainingComponent
