@@ -1,10 +1,12 @@
-from pandas import DataFrame
-from dask.dataframe import DataFrame as DaskDataFrame
 from abc import ABC, abstractstaticmethod
-from typing import Any, List, Dict, Optional, Set, Union
+from typing import Any, Dict, List, Optional
+
 from dagster import AssetMaterialization, EventMetadata
-from .utils.typing import is_pandas_dataframe, is_dask_dataframe, is_mlflow_run
+from dask.dataframe import DataFrame as DaskDataFrame
+from pandas import DataFrame
+
 from .mlflow import MLFlowRun
+from .utils.typing import is_dask_dataframe, is_mlflow_run, is_pandas_dataframe
 
 
 def list_to_string(list: List[Any]) -> str:
@@ -38,7 +40,10 @@ class DaskDataFrameMetaData(MetaData):
         if not is_dask_dataframe(object):
             raise ValueError("Object is not a dask dataframe")
 
-        return {"columns": list_to_string(object.columns)}
+        return {
+            "columns": list_to_string(object.columns), 
+            "dask": 1,
+        }
 
 
 class MLFlowRunMetaData(MetaData):
